@@ -21,9 +21,8 @@ sys.path.insert(0, os.path.abspath('../..'))
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
-    'sphinx.ext.autodoc',
+    # 'sphinx.ext.autodoc',
     # 'sphinx.ext.intersphinx',
-    'reno.sphinxext',
     'openstackdocstheme',
     'oslo_config.sphinxext',
 ]
@@ -92,4 +91,6 @@ autodoc_mock_imports = [
     #    for backward compatibility. SIGUSR1 will no longer be registered
     #    in a future release, so please use SIGUSR2 to generate reports.
     'oslo_reports',
+    # "no IPRoute module for the platform" on OS X
+    'neutron.agent.linux.ip_lib',
 ]
